@@ -758,6 +758,8 @@ mod tests {
                 members: vec![SplinterNode {
                     node_id: "node_id".into(),
                     endpoints: vec!["".into()],
+                    #[cfg(feature = "challenge-authorization")]
+                    public_key: None,
                 }],
                 authorization_type: AuthorizationType::Trust,
                 persistence: PersistenceType::Any,
@@ -813,6 +815,8 @@ mod tests {
                 members: vec![SplinterNode {
                     node_id: "node_id".into(),
                     endpoints: vec!["".into()],
+                    #[cfg(feature = "challenge-authorization")]
+                    public_key: None,
                 }],
                 authorization_type: AuthorizationType::Trust,
                 persistence: PersistenceType::Any,
