@@ -284,8 +284,6 @@ impl std::fmt::Display for AdminConsensusManagerError {
 pub enum AdminError {
     ConsensusFailed(AdminConsensusManagerError),
     MessageTypeUnset,
-    #[cfg(not(feature = "proposal-removal"))]
-    MessageTypeUnhandled,
 }
 
 impl Error for AdminError {
@@ -293,8 +291,6 @@ impl Error for AdminError {
         match self {
             AdminError::ConsensusFailed(err) => Some(err),
             AdminError::MessageTypeUnset => None,
-            #[cfg(not(feature = "proposal-removal"))]
-            AdminError::MessageTypeUnhandled => None,
         }
     }
 }
@@ -304,8 +300,6 @@ impl std::fmt::Display for AdminError {
         match self {
             AdminError::ConsensusFailed(err) => write!(f, "admin consensus failed: {}", err),
             AdminError::MessageTypeUnset => write!(f, "received message with unset type"),
-            #[cfg(not(feature = "proposal-removal"))]
-            AdminError::MessageTypeUnhandled => write!(f, "received message with unhandled type"),
         }
     }
 }
