@@ -28,10 +28,8 @@
 
 #[cfg(feature = "diesel")]
 mod diesel;
-mod error;
 
 #[cfg(feature = "postgres")]
 pub use self::diesel::postgres::run_migrations as run_postgres_migrations;
 #[cfg(feature = "sqlite")]
 pub use self::diesel::sqlite::run_migrations as run_sqlite_migrations;
-pub use self::error::MigrationError;
