@@ -26,8 +26,8 @@ use crate::protos::prelude::*;
 
 use crate::network::auth::{
     state_machine::trust_v0::{TrustV0AuthorizationAction, TrustV0AuthorizationState},
-    AuthorizationAction, AuthorizationActionError, AuthorizationManagerStateMachine,
-    AuthorizationState,
+    AuthorizationActionError, AuthorizationManagerStateMachine, AuthorizationRemoteAction,
+    AuthorizationRemoteState, Identity,
 };
 
 pub struct AuthorizedHandler {
@@ -59,9 +59,9 @@ impl Handler for AuthorizedHandler {
             "Received authorize message from {}",
             context.source_connection_id()
         );
-        match self.auth_manager.next_state(
+        match self.auth_manager.next_remote_state(
             context.source_connection_id(),
-            AuthorizationAction::TrustV0(TrustV0AuthorizationAction::RemoteAuthorizing),
+            AuthorizationRemoteAction::TrustV0(TrustV0AuthorizationAction::RemoteAuthorizing),
         ) {
             Err(err) => {
                 warn!(
@@ -108,9 +108,9 @@ impl Handler for ConnectRequestHandler {
         sender: &dyn MessageSender<Self::Source>,
     ) -> Result<(), DispatchError> {
         let connect_request = ConnectRequest::from_proto(msg)?;
-        match self.auth_manager.next_state(
+        match self.auth_manager.next_remote_state(
             context.source_connection_id(),
-            AuthorizationAction::Connecting,
+            AuthorizationRemoteAction::Connecting,
         ) {
             Err(AuthorizationActionError::AlreadyConnecting) => {
                 debug!(
@@ -125,7 +125,7 @@ impl Handler for ConnectRequestHandler {
                     err
                 );
             }
-            Ok(AuthorizationState::TrustV0(TrustV0AuthorizationState::Connecting)) => {
+            Ok(AuthorizationRemoteState::TrustV0(TrustV0AuthorizationState::Connecting)) => {
                 debug!("Beginning handshake for {}", context.source_connection_id(),);
                 // Send a connect request of our own
 
@@ -252,10 +252,12 @@ impl Handler for TrustRequestHandler {
         sender: &dyn MessageSender<Self::Source>,
     ) -> Result<(), DispatchError> {
         let trust_request = TrustRequest::from_proto(msg)?;
-        match self.auth_manager.next_state(
+        match self.auth_manager.next_remote_state(
             context.source_connection_id(),
-            AuthorizationAction::TrustV0(TrustV0AuthorizationAction::TrustIdentifyingV0(
-                trust_request.identity,
+            AuthorizationRemoteAction::TrustV0(TrustV0AuthorizationAction::TrustIdentifyingV0(
+                Identity::Trust {
+                    identity: trust_request.identity,
+                },
             )),
         ) {
             Err(err) => {
@@ -265,14 +267,14 @@ impl Handler for TrustRequestHandler {
                     err
                 );
             }
-            Ok(AuthorizationState::TrustV0(TrustV0AuthorizationState::RemoteIdentified(
-                identity,
+            Ok(AuthorizationRemoteState::TrustV0(TrustV0AuthorizationState::RemoteIdentified(
+                Identity::Trust { identity },
             )))
-            | Ok(AuthorizationState::AuthComplete(Some(identity))) => {
+            | Ok(AuthorizationRemoteState::Done(Identity::Trust { identity })) => {
                 debug!(
                     "Sending Authorized message to connection {} after receiving identity {}",
                     context.source_connection_id(),
-                    identity,
+                    identity
                 );
                 let auth_msg = AuthorizationMessage::Authorized(Authorized);
                 let msg_bytes = IntoBytes::<network::NetworkMessage>::into_bytes(
